################################
Amazon Braket features
################################

Learn more about the indivudal features of Amazon Braket.

.. toctree::
    :maxdepth: 2

**************************
`Getting notifications when a task completes <https://github.com/aws/amazon-braket-examples/blob/main/examples/braket_features/Getting_notifications_when_a_task_completes/Getting_notifications_when_a_task_completes.ipynb>`_
**************************

This tutorial illustrates how Amazon Braket integrates with Amazon EventBridge for 
event-based processing. In the tutorial, you will learn how to configure Amazon Braket 
and Amazon Eventbridge to receive text notification about task completions on your phone. 

**************************
`Allocating Qubits on QPU Devices <https://github.com/aws/amazon-braket-examples/blob/main/examples/braket_features/Allocating_Qubits_on_QPU_Devices.ipynb>`_
**************************

This tutorial explains how you can use the Amazon Braket SDK to allocate the qubit 
selection for your circuits manually, when running on QPUs.

**************************
`Getting Devices and Checking Device Properties <https://github.com/aws/amazon-braket-examples/blob/main/examples/braket_features/Getting_Devices_and_Checking_Device_Properties.ipynb>`_
**************************

This example shows how to interact with the Amazon Braket GetDevice API to 
retrieve Amazon Braket devices (such as simulators and QPUs) programatically, 
and how to gain access to their properties.

**************************
`Using the tensor network simulator TN1 <https://github.com/aws/amazon-braket-examples/blob/main/examples/braket_features/Using_the_tensor_network_simulator_TN1.ipynb>`_
**************************

This notebook introduces the Amazon Braket managed tensor network simulator, TN1. 
You will learn about how TN1 works, how to use it, and which problems are best suited to run on TN1.


**************************
`Simulating noise on Amazon Braket <https://github.com/aws/amazon-braket-examples/blob/main/examples/braket_features/Simulating_Noise_On_Amazon_Braket.ipynb>`_
**************************

This notebook provides a detailed overview of noise simulation on Amazon Braket.
You will learn how to define noise channels, apply noise to new or existing circuits, and run those circuits
on the Amazon Braket noise simulators.
